Christopher Clements - Spredfast Social Suite and Saloon 2016
Description: Creating an immersive tech lounge experience at SXSWi.
Keywords: sxsw,tech,demo,Event,lounge

# Spredfast Social Suite and Saloon 2016

Brief
Spredfast wanted to follow it's successful 2015 SXSW presence with a stand-out, expanded suite experience and equally enticing party at the Moody Theater.
Process
We leveraged a public focus on space exploration, along with the recently released NASA Apollo missions image archive to create a truly unique, on-trend event experience that earned Spredfast a seat on CNBC's best brand experiences at SXSW list. Also on the list were brands like McDonald's, Spotify, American Greetings, Gatorade, Visa and Deloitte Digital.
Competencies
Creative direction, Graphic design, Event design, UX design, Illustration
Key Metrics
Event attendance tied to pipeline influence, social engagement, hashtag usage, press coverage, number of sales meetings planned/completed.
Theme concepting sketches:
Style guide:
Asset examples:
Photos from the event:
↑Back to Top